@@ -1,11 +1,11 @@
 //! @file a68g-common.h
 //! @author J. Marcel van der Veer
-//!
+
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
 //! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
-//!
+
 //! @section License
 //!
 //! This program is free software; you can redistribute it and/or modify it 
@@ -105,7 +105,6 @@ struct UNIC_T
   char *fun;
 };
 
-//
 
 #define A68(z)         (common.z)
 #define A68_JOB        A68 (job)
@@ -230,21 +229,16 @@ struct A68_THREAD_CONTEXT
 // Set an upper limit for number of threads.
 // Note that _POSIX_THREAD_THREADS_MAX may be ULONG_MAX.
 
-#define THREAD_LIMIT   256
+#define THREAD_LIMIT 256
 
-#if (_POSIX_THREAD_THREADS_MAX < THREAD_LIMIT)
-#undef  THREAD_LIMIT
-#define THREAD_LIMIT   _POSIX_THREAD_THREADS_MAX
-#endif
-
-#if !defined _POSIX_THREAD_THREADS_MAX
-#define _POSIX_THREAD_THREADS_MAX	(THREAD_LIMIT)
-#endif
-
-#if (_POSIX_THREAD_THREADS_MAX < THREAD_LIMIT)
-#define THREAD_MAX     (_POSIX_THREAD_THREADS_MAX)
+#if defined (_POSIX_THREAD_THREADS_MAX)
+  #if ((_POSIX_THREAD_THREADS_MAX) < THREAD_LIMIT)
+    #define THREAD_MAX (_POSIX_THREAD_THREADS_MAX)
+  #else
+    #define THREAD_MAX (THREAD_LIMIT)
+  #endif
 #else
-#define THREAD_MAX     (THREAD_LIMIT)
+  #define THREAD_MAX (THREAD_LIMIT)
 #endif
 
 typedef struct PARALLEL_GLOBALS_T PARALLEL_GLOBALS_T;
