@@ -1,11 +1,11 @@
 //! @file a68g-optimiser.h
 //! @author J. Marcel van der Veer
-//!
+
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
 //! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
-//!
+
 //! @section License
 //!
 //! This program is free software; you can redistribute it and/or modify it 
@@ -26,54 +26,58 @@
 #if !defined (__A68G_OPTIMISER_H__)
 #define __A68G_OPTIMISER_H__
 
-extern BOOL_T constant_unit (NODE_T *);
-extern BOOL_T folder_mode (MOID_T *);
-extern void build_script (void);
-extern void compiler (FILE_T);
-extern void load_script (void);
-extern void push_unit (NODE_T *);
-extern void rewrite_script_source (void);
+BOOL_T constant_unit (NODE_T *);
+BOOL_T folder_mode (MOID_T *);
+void build_script (void);
+void load_script (void);
+void plugin_driver_clean (int);
+void plugin_driver_code (void);
+void plugin_driver_compile (void);
+void plugin_driver_emit (FILE_T);
+void plugin_driver_genie (void);
+void push_unit (NODE_T *);
+void rewrite_script_source (void);
 
 // Library for code generator
 
-extern INT_T a68_add_int (INT_T, INT_T);
-extern INT_T a68_sub_int (INT_T, INT_T);
-extern INT_T a68_mul_int (INT_T, INT_T);
-extern INT_T a68_over_int (INT_T, INT_T);
-extern INT_T a68_mod_int (INT_T, INT_T);
-extern REAL_T a68_div_int (INT_T, INT_T);
+INT_T a68_add_int (INT_T, INT_T);
+INT_T a68_sub_int (INT_T, INT_T);
+INT_T a68_mul_int (INT_T, INT_T);
+INT_T a68_over_int (INT_T, INT_T);
+INT_T a68_mod_int (INT_T, INT_T);
+REAL_T a68_div_int (INT_T, INT_T);
 
-extern void a68_ln_complex (A68_REAL *, A68_REAL *);
-extern void a68_sqrt_complex (A68_REAL *, A68_REAL *);
-extern void a68_sin_complex (A68_REAL *, A68_REAL *);
-extern void a68_cos_complex (A68_REAL *, A68_REAL *);
-extern void a68_tan_complex (A68_REAL *, A68_REAL *);
-extern void a68_asin_complex (A68_REAL *, A68_REAL *);
-extern void a68_acos_complex (A68_REAL *, A68_REAL *);
-extern void a68_atan_complex (A68_REAL *, A68_REAL *);
-extern void a68_sinh_complex (A68_REAL *, A68_REAL *);
-extern void a68_cosh_complex (A68_REAL *, A68_REAL *);
-extern void a68_tanh_complex (A68_REAL *, A68_REAL *);
-extern void a68_asinh_complex (A68_REAL *, A68_REAL *);
-extern void a68_acosh_complex (A68_REAL *, A68_REAL *);
-extern void a68_atanh_complex (A68_REAL *, A68_REAL *);
+void a68_ln_complex (A68_REAL *, A68_REAL *);
+void a68_sqrt_complex (A68_REAL *, A68_REAL *);
+void a68_sin_complex (A68_REAL *, A68_REAL *);
+void a68_cos_complex (A68_REAL *, A68_REAL *);
+void a68_tan_complex (A68_REAL *, A68_REAL *);
+void a68_asin_complex (A68_REAL *, A68_REAL *);
+void a68_acos_complex (A68_REAL *, A68_REAL *);
+void a68_atan_complex (A68_REAL *, A68_REAL *);
+void a68_sinh_complex (A68_REAL *, A68_REAL *);
+void a68_cosh_complex (A68_REAL *, A68_REAL *);
+void a68_tanh_complex (A68_REAL *, A68_REAL *);
+void a68_asinh_real_complex (A68_REAL *, A68_REAL *);
+void a68_acosh_real_complex (A68_REAL *, A68_REAL *);
+void a68_atanh_real_complex (A68_REAL *, A68_REAL *);
 
 // Operators that are inlined in compiled code
 
 #define a68_eq_complex(x, y) (RE (x) == RE (y) && IM (x) == IM (y))
 #define a68_ne_complex(x, y) (! a68_eq_complex (x, y))
 #define a68_plusab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) += (j), (i))
-#define a68_minusab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) -= (j), (i))
+#define a68_min_realusab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) -= (j), (i))
 #define a68_timesab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) *= (j), (i))
 #define a68_overab_int(i, j) (VALUE ((A68_INT *) ADDRESS (i)) /= (j), (i))
 #define a68_entier(x) ((int) floor (x))
 #define a68_plusab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) += (j), (i))
-#define a68_minusab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) -= (j), (i))
+#define a68_min_realusab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) -= (j), (i))
 #define a68_timesab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) *= (j), (i))
 #define a68_divab_real(i, j) (VALUE ((A68_REAL *) ADDRESS (i)) /= (j), (i))
 #define a68_re_complex(z) (RE (z))
 #define a68_im_complex(z) (IM (z))
-#define a68_abs_complex(z) a68_hypot (RE (z), IM (z))
+#define a68_abs_real_complex(z) a68_hypot_real (RE (z), IM (z))
 #define a68_arg_complex(z) atan2 (IM (z), RE (z))
 
 #define a68_i_complex(z, re, im) {\
@@ -82,7 +86,7 @@ extern void a68_atanh_complex (A68_REAL *, A68_REAL *);
   RE (z) = re;\
   IM (z) = im;}
 
-#define a68_minus_complex(z, x) {\
+#define a68_min_realus_complex(z, x) {\
   STATUS_RE (z) = INIT_MASK;\
   STATUS_IM (z) = INIT_MASK;\
   RE (z) = -RE (x);\
