@@ -1,11 +1,11 @@
 //! @file a68g-types.h
 //! @author J. Marcel van der Veer
-//!
+
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
 //! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
-//!
+
 //! @section License
 //!
 //! This program is free software; you can redistribute it and/or modify it 
@@ -359,7 +359,7 @@ struct A68_BITS
 struct A68_BYTES
 {
   STATUS_MASK_T status;
-  char value[BYTES_WIDTH + 1];
+  char value[A68_BYTES_WIDTH + 1];
 } ALIGNED;
 
 struct A68_CHANNEL
@@ -407,7 +407,7 @@ struct A68_FORMAT
 struct A68_LONG_BYTES
 {
   STATUS_MASK_T status;
-  char value[LONG_BYTES_WIDTH + 1];
+  char value[A68_LONG_BYTES_WIDTH + 1];
 } ALIGNED;
 
 //! @struct A68_PROCEDURE
